<?php
/**
 * Delimited list display style.
 */
class views_plugin_style_delimited_list extends views_plugin_style {
  /**
   * Default options.
   */
  function option_definition() {
    $options = parent::option_definition();
    $options['delimiter'] = array('default' => ', ');
    $options['conjunctive'] = array('default' => ' and ');
    $options['when_two'] = array('default' => 'delimiter');
    $options['delimit_before_last'] = array('default' => 1);
    return $options;
  }

  /**
   * Add widgets for selecting fields for the feature rotator.
   */
  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);

    $form['delimiter'] = array(
      '#type' => 'textfield',
      '#title' => t('Delimiter text'),
      '#default_value' => $this->options['delimiter'],
      '#description' => t('This is the text that will be used for delimiting the list. Include leading and/or trailing spaces as desired. Default value: ", ".'),
    );
    $form['conjunctive'] = array(
      '#type' => 'textfield',
      '#title' => t('Conjunctive text'),
      '#default_value' => $this->options['conjunctive'],
      '#description' => t('What to use as the conjunctive for the list. Include leading and/or trailing spaces as desired. When used with the delimiter in a list of three or more items, the leading space in the conjunctive is typically collapsed with the trailing space in the final delimier. Default value: " and ".'),
    );
    $form['length_behavior'] = array(
      '#type' => 'fieldset',
      '#title' => t('List length-dependent behavior'),
      '#tree' => FALSE,
    );
    $form['length_behavior']['when_two'] = array(
      '#type' => 'radios',
      '#parents' => array('style_options', 'when_two'),
      '#title' => t('What to use when there are only two items'),
      '#options' => array(
        '' => t('Nothing'),
        'delimiter' => t('Delimiter text'),
        'conjunctive' => t('Conjunctive'),
      ),
      '#default_value' => $this->options['when_two'],
      '#description' => t('When there are two items in the list, this option specifies what goes between the items. Default value: Delimiter text.'),
    );
    $form['length_behavior']['delimit_before_last'] = array(
      '#type' => 'checkbox',
      '#parents' => array('style_options', 'delimit_before_last'),
      '#title' => t('Delimit before last in long list'),
      '#default_value' => $this->options['delimit_before_last'],
      '#description' => t('In lists of three or more items, this option determines whether or not to use the delimiter before the final item. This is useful for distinguishing between U.S. English and U.K. English.'),
    );
  }
}